Index: main/waeup.kofa/trunk/src/waeup/kofa/university/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/__init__.py	(revision 7811)
@@ -1,10 +1,10 @@
 # Make this a package.
-from waeup.sirp.university.course import Course
-from waeup.sirp.university.coursescontainer import CoursesContainer
-from waeup.sirp.university.certificate import Certificate
-from waeup.sirp.university.certificatescontainer import CertificatesContainer
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
-from waeup.sirp.university.facultiescontainer import FacultiesContainer
+from waeup.kofa.university.course import Course
+from waeup.kofa.university.coursescontainer import CoursesContainer
+from waeup.kofa.university.certificate import Certificate
+from waeup.kofa.university.certificatescontainer import CertificatesContainer
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
+from waeup.kofa.university.facultiescontainer import FacultiesContainer
 __all__ = (
     'Course', 'CoursesContainer',
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/api.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/api.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/api.txt	(revision 7811)
@@ -1,6 +1,6 @@
-:mod:`waeup.sirp.university` -- academic components
+:mod:`waeup.kofa.university` -- academic components
 ***************************************************
 
-.. module:: waeup.sirp.university
+.. module:: waeup.kofa.university
 
 Components that represent academic 'core' stuff like faculties, 
@@ -9,5 +9,5 @@
 ==========
 
-The :mod:`waeup.sirp.university` module provides the following submodules:
+The :mod:`waeup.kofa.university` module provides the following submodules:
 
 .. toctree::
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py	(revision 7811)
@@ -26,9 +26,9 @@
 import grok
 from zope.interface import Interface
-from waeup.sirp.interfaces import IBatchProcessor
-from waeup.sirp.university.interfaces import (
+from waeup.kofa.interfaces import IBatchProcessor
+from waeup.kofa.university.interfaces import (
     IFacultiesContainer, IFaculty, ICourse, IDepartment, ICertificate,
     ICertificateCourse)
-from waeup.sirp.utils.batching import BatchProcessor
+from waeup.kofa.utils.batching import BatchProcessor
 
 class FacultyProcessor(BatchProcessor):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""SIRP certificates
+"""KOFA certificates
 """
 import grok
@@ -24,7 +24,7 @@
 from zope.component.interfaces import IFactory, ComponentLookupError
 from zope.interface import implementedBy
-from waeup.sirp.university.interfaces import (
+from waeup.kofa.university.interfaces import (
     ICertificate, ICertificateAdd, ICertificateCourse)
-from waeup.sirp.university.vocabularies import course_levels
+from waeup.kofa.university.vocabularies import course_levels
 
 class Certificate(grok.Container):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/certificate.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.certificate` -- Certificates for SIRP
+:mod:`waeup.kofa.university.certificate` -- Certificates for KOFA
 ******************************************************************
 
-.. module:: waeup.sirp.university.certificate
+.. module:: waeup.kofa.university.certificate
 
 Components that represent and manage certificates.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -25,10 +25,10 @@
    All parameters are optional:
 
-     >>> from waeup.sirp.university.certificate import Certificate
+     >>> from waeup.kofa.university.certificate import Certificate
      >>> mycertificate = Certificate()
 
    Certificates have the attributes required by the `ICertificate` interface:
 
-     >>> from waeup.sirp.university.interfaces import ICertificate
+     >>> from waeup.kofa.university.interfaces import ICertificate
      >>> ICertificate.providedBy(mycertificate)
      True
@@ -99,5 +99,5 @@
 
       Add a referrer of a course. A course is an object implementing
-      :class:`waeup.sirp.interfaces.ICourse`.
+      :class:`waeup.kofa.interfaces.ICourse`.
 
       Please don't be confused by the term 'referrer'. As course objects 
@@ -159,5 +159,5 @@
      >>> mycertificate = createObject(u'waeup.Certificate')
      >>> mycertificate
-     <waeup.sirp.university.certificate.Certificate object at 0x...>
+     <waeup.kofa.university.certificate.Certificate object at 0x...>
 
    The factory complies with the specifications from the
@@ -166,5 +166,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.certificate import CertificateFactory
+     >>> from waeup.kofa.university.certificate import CertificateFactory
      >>> verifyClass(IFactory, CertificateFactory)
      True
@@ -175,5 +175,5 @@
      >>> certificate_factory = CertificateFactory()
      >>> certificate_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.certificate.Certificate>
+     <implementedBy waeup.kofa.university.certificate.Certificate>
 
 
@@ -193,5 +193,5 @@
      >>> mycertificatecourse = createObject(u'waeup.CertificateCourse')
      >>> mycertificatecourse
-     <waeup.sirp.university.certificate.CertificateCourse object at 0x...>
+     <waeup.kofa.university.certificate.CertificateCourse object at 0x...>
 
    The factory complies with the specifications from the
@@ -200,5 +200,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.certificate import CertificateCourseFactory
+     >>> from waeup.kofa.university.certificate import CertificateCourseFactory
      >>> verifyClass(IFactory, CertificateCourseFactory)
      True
@@ -209,5 +209,5 @@
      >>> certcourse_factory = CertificateCourseFactory()
      >>> certcourse_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.certificate.CertificateCourse>
+     <implementedBy waeup.kofa.university.certificate.CertificateCourse>
 
 
@@ -244,8 +244,8 @@
 We can create certificates:
 
-    >>> from waeup.sirp.university.certificate import Certificate
+    >>> from waeup.kofa.university.certificate import Certificate
     >>> mycertificate = Certificate()
     >>> mycertificate
-    <waeup.sirp.university.certificate.Certificate object at 0x...>
+    <waeup.kofa.university.certificate.Certificate object at 0x...>
 
 Another way to create certificates is by asking for a factory called
@@ -256,5 +256,5 @@
     >>> mycertificate = createObject(u'waeup.Certificate')
     >>> mycertificate
-    <waeup.sirp.university.certificate.Certificate object at 0x...>
+    <waeup.kofa.university.certificate.Certificate object at 0x...>
 
 CertificateCourses
@@ -264,6 +264,6 @@
 :class:`ICertificateCourse` interface:
 
-    >>> from waeup.sirp.university.interfaces import ICertificateCourse
-    >>> from waeup.sirp.university.certificate import CertificateCourse
+    >>> from waeup.kofa.university.interfaces import ICertificateCourse
+    >>> from waeup.kofa.university.certificate import CertificateCourse
     >>> mycertcourse = CertificateCourse(None, 200, False)
     >>> ICertificateCourse.providedBy(mycertcourse)
@@ -280,5 +280,5 @@
     >>> mycertcourse = createObject(u'waeup.CertificateCourse')
     >>> mycertcourse
-    <waeup.sirp.university.certificate.CertificateCourse object at 0x...>
+    <waeup.kofa.university.certificate.CertificateCourse object at 0x...>
 
 .. _removecertificatecourses:
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.py	(revision 7811)
@@ -23,6 +23,6 @@
 from zope.component import queryUtility
 from zope.interface import implementedBy
-from waeup.sirp.interfaces import DuplicationError
-from waeup.sirp.university.interfaces import (
+from waeup.kofa.interfaces import DuplicationError
+from waeup.kofa.university.interfaces import (
     ICertificatesContainer, ICertificate)
 
@@ -31,5 +31,5 @@
 
     A :class:`CertificatesContainer` stores
-    :class:`waeup.sirp.university.Certificate` instances.
+    :class:`waeup.kofa.university.Certificate` instances.
 
     It is a :class:`grok.Container` basically acting like a standard
@@ -52,5 +52,5 @@
 
         The `certificate` must be an object implementing
-        :class:`waeup.sirp.university.interfaces.ICertificate`. If
+        :class:`waeup.kofa.university.interfaces.ICertificate`. If
         not, a :exc:`TypeError` is raised.
 
@@ -60,6 +60,6 @@
         If the `code` attribute of `certificate` is already in use by
         another certificate stored in the local site
-        (:class:`waeup.sirp.app.University` instance), then a
-        :exc:`waeup.sirp.interfaces.DuplicationError` will be raised.
+        (:class:`waeup.kofa.app.University` instance), then a
+        :exc:`waeup.kofa.interfaces.DuplicationError` will be raised.
 
         If `name` is already used as a key, a :exc:`KeyError` will be
@@ -92,5 +92,5 @@
 
         The certificate must be an object implementing
-        :class:`waeup.sirp.university.interfaces.ICertificate`. If
+        :class:`waeup.kofa.university.interfaces.ICertificate`. If
         not, a :exc:`TypeError` is raised.
 
@@ -98,6 +98,6 @@
         `code` attribute as key. If this key is already used for
         another certificate stored in the local site
-        (:class:`waeup.sirp.app.University` instance), then a
-        :exc:`waeup.sirp.interfaces.DuplicationError` will be raised.
+        (:class:`waeup.kofa.app.University` instance), then a
+        :exc:`waeup.kofa.interfaces.DuplicationError` will be raised.
         """
         self[getattr(certificate, 'code', None)] = certificate
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/certificatescontainer.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.certificatescontainer` -- Certificate containers
+:mod:`waeup.kofa.university.certificatescontainer` -- Certificate containers
 ****************************************************************************
 
-.. module:: waeup.sirp.university.certificatescontainer
+.. module:: waeup.kofa.university.certificatescontainer
 
 Containers for certificates.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -26,14 +26,14 @@
    :class:`CertificatesContainer` instances are instances of
    :class:`grok.Container` that hold and manage instances of
-   :class:`waeup.sirp.university.certificate.Certificate`.
+   :class:`waeup.kofa.university.certificate.Certificate`.
 
-     >>> from waeup.sirp.university.certificatescontainer import CertificatesContainer
+     >>> from waeup.kofa.university.certificatescontainer import CertificatesContainer
      >>> mycontainer = CertificatesContainer()
      >>> mycontainer
-     <waeup.sirp.university.certificatescontainer.CertificatesContainer object at 0x...>
+     <waeup.kofa.university.certificatescontainer.CertificatesContainer object at 0x...>
 
    Certificate containers provide `ICertificatesContainer`:
 
-     >>> from waeup.sirp.university.interfaces import ICertificatesContainer
+     >>> from waeup.kofa.university.interfaces import ICertificatesContainer
      >>> ICertificatesContainer.providedBy(mycontainer)
      True
@@ -57,7 +57,7 @@
 
       *certificate* must be an instance of
-      :class:`waeup.sirp.university.certificate.Certificate`:
+      :class:`waeup.kofa.university.certificate.Certificate`:
 
-        >>> from waeup.sirp.university.certificatescontainer import (
+        >>> from waeup.kofa.university.certificatescontainer import (
         ...   CertificatesContainer)
         >>> mycontainer = CertificatesContainer()
@@ -69,5 +69,5 @@
       The key of added items is the ``code`` attribute:
 
-        >>> from waeup.sirp.university.certificate import Certificate
+        >>> from waeup.kofa.university.certificate import Certificate
         >>> mycertificate = Certificate(code='CERTIFICATE1')
         >>> mycontainer.addCertificate(mycertificate)
@@ -104,5 +104,5 @@
      >>> mycertificatescontainer = createObject(u'waeup.CertificatesContainer')
      >>> mycertificatescontainer
-     <waeup.sirp.university.certificatescontainer.CertificatesContainer object at 0x...>
+     <waeup.kofa.university.certificatescontainer.CertificatesContainer object at 0x...>
 
    The factory complies with the specifications from the
@@ -111,5 +111,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.certificatescontainer import (
+     >>> from waeup.kofa.university.certificatescontainer import (
      ...   CertificatesContainerFactory)
      >>> verifyClass(IFactory, CertificatesContainerFactory)
@@ -121,5 +121,5 @@
      >>> certificatescontainer_factory = CertificatesContainerFactory()
      >>> certificatescontainer_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.certificatescontainer.CertificatesContainer>
+     <implementedBy waeup.kofa.university.certificatescontainer.CertificatesContainer>
 
 
@@ -132,5 +132,5 @@
 We can easily create `CertificatesContainers`:
 
-    >>> from waeup.sirp.university.certificatescontainer import CertificatesContainer
+    >>> from waeup.kofa.university.certificatescontainer import CertificatesContainer
     >>> mycontainer = CertificatesContainer()
 
@@ -143,5 +143,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.CertificatesContainer')
-    <waeup.sirp.university.certificatescontainer.CertificatesContainer object at 0x...>
+    <waeup.kofa.university.certificatescontainer.CertificatesContainer object at 0x...>
 
 This way we get a thing that implements ICertificatesContainer without
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/course.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/course.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/course.py	(revision 7811)
@@ -23,5 +23,5 @@
 from zope.component import getUtility
 from zope.component.interfaces import IFactory, ComponentLookupError
-from waeup.sirp.university.interfaces import ICourse, ICourseAdd
+from waeup.kofa.university.interfaces import ICourse, ICourseAdd
 
 class Course(grok.Model):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/course.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/course.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/course.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.course` -- Courses
+:mod:`waeup.kofa.university.course` -- Courses
 **********************************************
 
-.. module:: waeup.sirp.university.course
+.. module:: waeup.kofa.university.course
 
 Components that represent courses.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 Content Classes (models and containers)
@@ -23,13 +23,13 @@
    All parameters are optional:
 
-     >>> from waeup.sirp.university.course import Course
+     >>> from waeup.kofa.university.course import Course
      >>> mycourse = Course()
      >>> mycourse
-     <waeup.sirp.university.course.Course object at 0x...>
+     <waeup.kofa.university.course.Course object at 0x...>
 
    Course instances have the attributes required by the
-   :class:`waeup.sirp.interfaces.ICourse` interface:
+   :class:`waeup.kofa.interfaces.ICourse` interface:
 
-     >>> from waeup.sirp.university.interfaces import ICourse
+     >>> from waeup.kofa.university.interfaces import ICourse
      >>> ICourse.providedBy(mycourse)
      True
@@ -101,5 +101,5 @@
      >>> mycourse = createObject(u'waeup.Course')
      >>> mycourse
-     <waeup.sirp.university.course.Course object at 0x...>
+     <waeup.kofa.university.course.Course object at 0x...>
 
    The factory complies with the specifications from the
@@ -108,5 +108,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.course import CourseFactory
+     >>> from waeup.kofa.university.course import CourseFactory
      >>> verifyClass(IFactory, CourseFactory)
      True
@@ -117,5 +117,5 @@
      >>> course_factory = CourseFactory()
      >>> course_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.course.Course>
+     <implementedBy waeup.kofa.university.course.Course>
 
 Examples
@@ -128,8 +128,8 @@
 class and calling the constructor:
 
-    >>> from waeup.sirp.university.course import Course
+    >>> from waeup.kofa.university.course import Course
     >>> mycourse = Course()
     >>> mycourse
-    <waeup.sirp.university.course.Course object at 0x...>
+    <waeup.kofa.university.course.Course object at 0x...>
 
 Another way to create courses is by asking for a factory called
@@ -140,4 +140,4 @@
     >>> mycourse = createObject(u'waeup.Course')
     >>> mycourse
-    <waeup.sirp.university.course.Course object at 0x...>
+    <waeup.kofa.university.course.Course object at 0x...>
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/courserefs.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/courserefs.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/courserefs.txt	(revision 7811)
@@ -16,5 +16,5 @@
 As correct deletion of referrer needs support of catalogs (we lookup
 catalogs to find referrers), we need a fully blown ZODB here,
-including an instance of :class:`waeup.sirp.app.University`, as this is our
+including an instance of :class:`waeup.kofa.app.University`, as this is our
 `ISite` object where the catalogs are stored.
 
@@ -23,5 +23,5 @@
 and course certificates:
 
-    >>> from waeup.sirp.app import University
+    >>> from waeup.kofa.app import University
     >>> root = getRootFolder()
     >>> root['app'] = University()
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.py	(revision 7811)
@@ -23,6 +23,6 @@
 from zope.catalog.interfaces import ICatalog
 from zope.component import queryUtility
-from waeup.sirp.interfaces import DuplicationError
-from waeup.sirp.university.interfaces import ICoursesContainer, ICourse
+from waeup.kofa.interfaces import DuplicationError
+from waeup.kofa.university.interfaces import ICoursesContainer, ICourse
 
 class CoursesContainer(grok.Container):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/coursescontainer.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.coursescontainer` -- Course containers
+:mod:`waeup.kofa.university.coursescontainer` -- Course containers
 ******************************************************************
 
-.. module:: waeup.sirp.university.coursescontainer
+.. module:: waeup.kofa.university.coursescontainer
 
 Containers for courses.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -26,14 +26,14 @@
    :class:`CoursesContainer` instances are instances of
    :class:`grok.Container` that hold and manage instances of
-   :class:`waeup.sirp.university.course.Course`.
+   :class:`waeup.kofa.university.course.Course`.
 
-     >>> from waeup.sirp.university.coursescontainer import CoursesContainer
+     >>> from waeup.kofa.university.coursescontainer import CoursesContainer
      >>> mycontainer = CoursesContainer()
      >>> mycontainer
-     <waeup.sirp.university.coursescontainer.CoursesContainer object at 0x...>
+     <waeup.kofa.university.coursescontainer.CoursesContainer object at 0x...>
 
    Course containers provide `ICoursesContainer`:
 
-     >>> from waeup.sirp.university.interfaces import ICoursesContainer
+     >>> from waeup.kofa.university.interfaces import ICoursesContainer
      >>> ICoursesContainer.providedBy(mycontainer)
      True
@@ -57,7 +57,7 @@
 
       *course* must be an instance of
-      :class:`waeup.sirp.university.course.Course`:
+      :class:`waeup.kofa.university.course.Course`:
 
-        >>> from waeup.sirp.university.coursescontainer import CoursesContainer
+        >>> from waeup.kofa.university.coursescontainer import CoursesContainer
         >>> mycontainer = CoursesContainer()
         >>> mycontainer.addCourse('blah')
@@ -68,5 +68,5 @@
       The key of added items is the ``code`` attribute:
 
-        >>> from waeup.sirp.university.course import Course
+        >>> from waeup.kofa.university.course import Course
         >>> mycourse = Course(code='COURSE1')
         >>> mycontainer.addCourse(mycourse)
@@ -103,5 +103,5 @@
      >>> mycoursescontainer = createObject(u'waeup.CoursesContainer')
      >>> mycoursescontainer
-     <waeup.sirp.university.coursescontainer.CoursesContainer object at 0x...>
+     <waeup.kofa.university.coursescontainer.CoursesContainer object at 0x...>
 
    The factory complies with the specifications from the
@@ -110,5 +110,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.coursescontainer import CoursesContainerFactory
+     >>> from waeup.kofa.university.coursescontainer import CoursesContainerFactory
      >>> verifyClass(IFactory, CoursesContainerFactory)
      True
@@ -119,5 +119,5 @@
      >>> coursescontainer_factory = CoursesContainerFactory()
      >>> coursescontainer_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.coursescontainer.CoursesContainer>
+     <implementedBy waeup.kofa.university.coursescontainer.CoursesContainer>
 
 
@@ -130,5 +130,5 @@
 We can easily create `CoursesContainers`:
 
-    >>> from waeup.sirp.university.coursescontainer import CoursesContainer
+    >>> from waeup.kofa.university.coursescontainer import CoursesContainer
     >>> mycontainer = CoursesContainer()
 
@@ -141,5 +141,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.CoursesContainer')
-    <waeup.sirp.university.coursescontainer.CoursesContainer object at 0x...>
+    <waeup.kofa.university.coursescontainer.CoursesContainer object at 0x...>
 
 This way we get a thing that implements ICoursesContainer without
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/department.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/department.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/department.py	(revision 7811)
@@ -22,8 +22,8 @@
 from zope.interface import implementedBy
 from zope.component import getUtility
-from waeup.sirp.university.coursescontainer import CoursesContainer
-from waeup.sirp.university.certificatescontainer import CertificatesContainer
-from waeup.sirp.interfaces import ISIRPUtils
-from waeup.sirp.university.interfaces import IDepartment, IDepartmentAdd
+from waeup.kofa.university.coursescontainer import CoursesContainer
+from waeup.kofa.university.certificatescontainer import CertificatesContainer
+from waeup.kofa.interfaces import IKOFAUtils
+from waeup.kofa.university.interfaces import IDepartment, IDepartmentAdd
 
 class Department(grok.Container):
@@ -73,5 +73,5 @@
 
     def longtitle(self):
-        insttypes_dict = getUtility(ISIRPUtils).getInstTypeDict()
+        insttypes_dict = getUtility(IKOFAUtils).getInstTypeDict()
         return "%s %s (%s)" % (
             insttypes_dict[self.title_prefix],
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/department.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/department.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/department.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.department` -- Departments
+:mod:`waeup.kofa.university.department` -- Departments
 ******************************************************
 
-.. module:: waeup.sirp.university.department
+.. module:: waeup.kofa.university.department
 
 Components that represent university departments.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 Content Classes (models and containers)
@@ -20,11 +20,11 @@
    Create a representation of a university department:
 
-     >>> from waeup.sirp.university.department import Department
+     >>> from waeup.kofa.university.department import Department
      >>> mydept = Department()
      >>> mydept
-     <waeup.sirp.university.department.Department object at 0x...>
+     <waeup.kofa.university.department.Department object at 0x...>
 
    Another way to create :class:`Department` instances is by asking
-   for a factory called ``waeup.sirp.Department``. This way we can create a
+   for a factory called ``waeup.kofa.Department``. This way we can create a
    department without importing a class:
 
@@ -32,10 +32,10 @@
      >>> mydept = createObject(u'waeup.Department')
      >>> mydept
-     <waeup.sirp.university.department.Department object at 0x...>
+     <waeup.kofa.university.department.Department object at 0x...>
 
    :class:`Department` instances have the attributes required by the
    `IDepartment` interface:
 
-     >>> from waeup.sirp.university.interfaces import IDepartment
+     >>> from waeup.kofa.university.interfaces import IDepartment
      >>> IDepartment.providedBy(mydept)
      True
@@ -86,5 +86,5 @@
 
         >>> mydept.courses
-        <waeup.sirp.university.coursescontainer.CoursesContainer object at 0x...>
+        <waeup.kofa.university.coursescontainer.CoursesContainer object at 0x...>
 
 
@@ -97,5 +97,5 @@
 
         >>> mydept.certificates
-        <waeup.sirp...certificatescontainer.CertificatesContainer object at 0x...>
+        <waeup.kofa...certificatescontainer.CertificatesContainer object at 0x...>
 
 Utilities
@@ -117,5 +117,5 @@
      >>> mydepartment = createObject(u'waeup.Department')
      >>> mydepartment
-     <waeup.sirp.university.department.Department object at 0x...>
+     <waeup.kofa.university.department.Department object at 0x...>
 
    The factory complies with the specifications from the
@@ -124,5 +124,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.department import DepartmentFactory
+     >>> from waeup.kofa.university.department import DepartmentFactory
      >>> verifyClass(IFactory, DepartmentFactory)
      True
@@ -133,3 +133,3 @@
      >>> department_factory = DepartmentFactory()
      >>> department_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.department.Department>
+     <implementedBy waeup.kofa.university.department.Department>
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/export.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/export.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/export.py	(revision 7811)
@@ -21,5 +21,5 @@
 import grok
 from cStringIO import StringIO
-from waeup.sirp.interfaces import ICSVExporter
+from waeup.kofa.interfaces import ICSVExporter
 
 class FacultyExporter(grok.GlobalUtility):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.py	(revision 7811)
@@ -19,6 +19,6 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.sirp.interfaces import ISIRPPluggable
-from waeup.sirp.university.interfaces import IFacultiesContainer, IFaculty
+from waeup.kofa.interfaces import IKOFAPluggable
+from waeup.kofa.university.interfaces import IFacultiesContainer, IFaculty
 
 class FacultiesContainer(grok.Container):
@@ -52,10 +52,10 @@
     """A plugin that creates container for faculties inside a university.
     """
-    grok.implements(ISIRPPluggable)
+    grok.implements(IKOFAPluggable)
     grok.name('faculties')
 
     def setup(self, site, name, logger):
         if 'faculties' in site.keys():
-            logger.warn('Could not create container for faculties in SIRP.')
+            logger.warn('Could not create container for faculties in KOFA.')
             return
         site['faculties'] = FacultiesContainer()
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/facultiescontainer.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.facultiescontainer` -- Faculty Containers
+:mod:`waeup.kofa.university.facultiescontainer` -- Faculty Containers
 *********************************************************************
 
-.. module:: waeup.sirp.university.facultiescontainer
+.. module:: waeup.kofa.university.facultiescontainer
 
 Components that represent faculty containers.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -20,8 +20,8 @@
    Create a faculty container:
 
-     >>> from waeup.sirp.university.facultiescontainer import FacultiesContainer
+     >>> from waeup.kofa.university.facultiescontainer import FacultiesContainer
      >>> mycontainer = FacultiesContainer()
      >>> mycontainer
-     <waeup.sirp.university.facultiescontainer.FacultiesContainer object at 0x...>
+     <waeup.kofa.university.facultiescontainer.FacultiesContainer object at 0x...>
 
    Another way to create :class:`FacultiesContainer` instances is by asking
@@ -32,10 +32,10 @@
      >>> mycontainer = createObject(u'waeup.FacultiesContainer')
      >>> mycontainer
-     <waeup.sirp.university.facultiescontainer.FacultiesContainer object at 0x...>
+     <waeup.kofa.university.facultiescontainer.FacultiesContainer object at 0x...>
 
    :class:`FacultiesContainer` instances have the attributes required by the
    `IFacultiesContainer` interface:
 
-     >>> from waeup.sirp.university.interfaces import IFacultiesContainer
+     >>> from waeup.kofa.university.interfaces import IFacultiesContainer
      >>> IFacultiesContainer.providedBy(mycontainer)
      True
@@ -60,10 +60,10 @@
       Regular faculties are accepted:
 
-        >>> from waeup.sirp.university.faculty import Faculty
+        >>> from waeup.kofa.university.faculty import Faculty
         >>> mycontainer.addFaculty(Faculty(title='Physics',
         ...                                code='FP'))
 
         >>> list(mycontainer.items())
-        [(u'FP', <waeup.sirp.university.faculty.Faculty object at 0x...>)]
+        [(u'FP', <waeup.kofa.university.faculty.Faculty object at 0x...>)]
 
 
@@ -77,10 +77,10 @@
 .. class:: AcademicsPlugin()
 
-   .. attribute:: grok.implements(ISIRPPluggable)
+   .. attribute:: grok.implements(IKOFAPluggable)
 
    This plugin component tells under which name (``faculties``) an
-   instance of academics stuff should be created in plain SIRP
+   instance of academics stuff should be created in plain KOFA
    instances. It also tells the factory name for FacultiesContainer
-   instances, which serve as root object for academics stuff in SIRP apps.
+   instances, which serve as root object for academics stuff in KOFA apps.
 
 
@@ -100,5 +100,5 @@
      >>> mycontainer = createObject(u'waeup.FacultiesContainer')
      >>> mycontainer
-     <waeup.sirp.university.facultiescontainer.FacultiesContainer object at 0x...>
+     <waeup.kofa.university.facultiescontainer.FacultiesContainer object at 0x...>
 
    The factory complies with the specifications from the
@@ -107,5 +107,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.facultiescontainer import (
+     >>> from waeup.kofa.university.facultiescontainer import (
      ...   FacultiesContainerFactory)
      >>> verifyClass(IFactory, FacultiesContainerFactory)
@@ -117,5 +117,5 @@
      >>> fac_container_factory = FacultiesContainerFactory()
      >>> fac_container_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.facultiescontainer.FacultiesContainer>
+     <implementedBy waeup.kofa.university.facultiescontainer.FacultiesContainer>
 
 Examples
@@ -124,10 +124,10 @@
 We can easily create `FacultiesContainers`:
 
-    >>> from waeup.sirp.university.facultiescontainer import FacultiesContainer
+    >>> from waeup.kofa.university.facultiescontainer import FacultiesContainer
     >>> mycontainer = FacultiesContainer()
 
 Faculty containers provide `IFacultiesContainer`:
 
-    >>> from waeup.sirp.university.interfaces import IFacultiesContainer
+    >>> from waeup.kofa.university.interfaces import IFacultiesContainer
     >>> IFacultiesContainer.providedBy(mycontainer)
     True
@@ -139,5 +139,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.FacultiesContainer')
-    <waeup.sirp.university.facultiescontainer.FacultiesContainer object at 0x...>
+    <waeup.kofa.university.facultiescontainer.FacultiesContainer object at 0x...>
 
 This way we get a thing that implements IFacultiesContainer without
@@ -165,5 +165,5 @@
 Okay, so we have to get a faculty first::
 
-    >>> from waeup.sirp.university.faculty import Faculty
+    >>> from waeup.kofa.university.faculty import Faculty
     >>> myfaculty = Faculty()
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.py	(revision 7811)
@@ -23,6 +23,6 @@
 from zope.interface import implementedBy
 from zope.component import getUtility
-from waeup.sirp.interfaces import ISIRPUtils
-from waeup.sirp.university.interfaces import (
+from waeup.kofa.interfaces import IKOFAUtils
+from waeup.kofa.university.interfaces import (
     IFaculty, IFacultyAdd, IDepartment)
 
@@ -61,5 +61,5 @@
 
     def longtitle(self):
-        insttypes_dict = getUtility(ISIRPUtils).getInstTypeDict()
+        insttypes_dict = getUtility(IKOFAUtils).getInstTypeDict()
         result = "%s %s (%s)" % (
             insttypes_dict[self.title_prefix],
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/faculty.txt	(revision 7811)
@@ -1,11 +1,11 @@
-:mod:`waeup.sirp.university.faculty` -- Faculties
+:mod:`waeup.kofa.university.faculty` -- Faculties
 *************************************************
 
-.. module:: waeup.sirp.university.faculty
+.. module:: waeup.kofa.university.faculty
 
 Components that represent university faculties.
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -21,8 +21,8 @@
    Create a representation of a university faculty:
 
-     >>> from waeup.sirp.university.faculty import Faculty
+     >>> from waeup.kofa.university.faculty import Faculty
      >>> myfac = Faculty()
      >>> myfac
-     <waeup.sirp.university.faculty.Faculty object at 0x...>
+     <waeup.kofa.university.faculty.Faculty object at 0x...>
 
    Another way to create :class:`Faculty` instances is by asking
@@ -33,10 +33,10 @@
      >>> myfac = createObject(u'waeup.Faculty')
      >>> myfac
-     <waeup.sirp.university.faculty.Faculty object at 0x...>
+     <waeup.kofa.university.faculty.Faculty object at 0x...>
 
    :class:`Faculty` instances have the attributes required by the
    `IFaculty` interface:
 
-     >>> from waeup.sirp.university.interfaces import IFaculty
+     >>> from waeup.kofa.university.interfaces import IFaculty
      >>> IFaculty.providedBy(myfac)
      True
@@ -62,10 +62,10 @@
       Regular departments are accepted:
 
-        >>> from waeup.sirp.university.department import Department
+        >>> from waeup.kofa.university.department import Department
         >>> myfac.addDepartment(Department(title='Physics',
         ...                                code='DP'))
 
         >>> list(myfac.items())
-        [(u'DP', <waeup.sirp.university.department.Department object at 0x...>)]
+        [(u'DP', <waeup.kofa.university.department.Department object at 0x...>)]
 
 
@@ -121,5 +121,5 @@
      >>> myfaculty = createObject(u'waeup.Faculty')
      >>> myfaculty
-     <waeup.sirp.university.faculty.Faculty object at 0x...>
+     <waeup.kofa.university.faculty.Faculty object at 0x...>
 
    The factory complies with the specifications from the
@@ -128,5 +128,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.sirp.university.faculty import FacultyFactory
+     >>> from waeup.kofa.university.faculty import FacultyFactory
      >>> verifyClass(IFactory, FacultyFactory)
      True
@@ -137,5 +137,5 @@
      >>> faculty_factory = FacultyFactory()
      >>> faculty_factory.getInterfaces()
-     <implementedBy waeup.sirp.university.faculty.Faculty>
+     <implementedBy waeup.kofa.university.faculty.Faculty>
 
 
@@ -145,8 +145,8 @@
 We can create faculties:
 
-    >>> from waeup.sirp.university.faculty import Faculty
+    >>> from waeup.kofa.university.faculty import Faculty
     >>> myfaculty = Faculty()
     >>> myfaculty
-    <waeup.sirp.university.faculty.Faculty object at 0x...>
+    <waeup.kofa.university.faculty.Faculty object at 0x...>
 
 Another way to create faculties is by asking for a factory called
@@ -157,5 +157,5 @@
     >>> myfaculty = createObject(u'waeup.Faculty')
     >>> myfaculty
-    <waeup.sirp.university.faculty.Faculty object at 0x...>
+    <waeup.kofa.university.faculty.Faculty object at 0x...>
 
 Faculty attributes
@@ -164,5 +164,5 @@
 Faculties have the attributes required by the `IFaculty` interface:
 
-    >>> from waeup.sirp.university.interfaces import IFaculty
+    >>> from waeup.kofa.university.interfaces import IFaculty
     >>> IFaculty.providedBy(myfaculty)
     True
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/interfaces.py	(revision 7811)
@@ -21,7 +21,7 @@
 from zope import schema
 from zope.interface import Attribute
-from waeup.sirp.interfaces import (ISIRPObject, ISIRPContainer)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.university.vocabularies import (
+from waeup.kofa.interfaces import (IKOFAObject, IKOFAContainer)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.university.vocabularies import (
     course_levels,
     CourseSource,
@@ -32,5 +32,5 @@
     )
 
-class IFaculty(ISIRPContainer):
+class IFaculty(IKOFAContainer):
     """Representation of a university faculty.
     """
@@ -73,5 +73,5 @@
 IFacultyAdd['code'].order =  IFaculty['code'].order
 
-class IFacultiesContainer(ISIRPContainer):
+class IFacultiesContainer(IKOFAContainer):
     """A container for faculties.
     """
@@ -80,5 +80,5 @@
 
         """
-class IDepartment(ISIRPObject):
+class IDepartment(IKOFAObject):
     """Representation of a department.
     """
@@ -124,5 +124,5 @@
 IDepartmentAdd['code'].order =  IDepartment['code'].order
 
-class ICoursesContainer(ISIRPContainer):
+class ICoursesContainer(IKOFAContainer):
     """A container for faculties.
     """
@@ -133,5 +133,5 @@
         """
 
-class ICourse(ISIRPObject):
+class ICourse(IKOFAObject):
     """Representation of a course.
     """
@@ -186,5 +186,5 @@
 ICourseAdd['code'].order =  ICourse['code'].order
 
-class ICertificate(ISIRPObject):
+class ICertificate(IKOFAObject):
     """Representation of a certificate.
     """
@@ -248,5 +248,5 @@
 ICertificateAdd['code'].order =  ICertificate['code'].order
 
-class ICertificatesContainer(ISIRPContainer):
+class ICertificatesContainer(IKOFAContainer):
     """A container for certificates.
     """
@@ -257,5 +257,5 @@
         """
 
-class ICertificateCourse(ISIRPObject):
+class ICertificateCourse(IKOFAObject):
     """A certificatecourse is referring a course and provides some own
        attributes.
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py	(revision 7811)
@@ -21,12 +21,12 @@
 
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.interfaces import IBatchProcessor
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
-from waeup.sirp.university.batching import (
+from waeup.kofa.interfaces import IBatchProcessor
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.university.batching import (
     FacultyProcessor, DepartmentProcessor, CourseProcessor,
     CertificateProcessor, CertificateCourseProcessor)
-from waeup.sirp.university.certificate import Certificate, CertificateCourse
-from waeup.sirp.university.course import Course
-from waeup.sirp.university.department import Department
+from waeup.kofa.university.certificate import Certificate, CertificateCourse
+from waeup.kofa.university.course import Course
+from waeup.kofa.university.department import Department
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_certificatescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_certificatescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_certificatescontainer.py	(revision 7811)
@@ -25,11 +25,11 @@
 from zope.interface.verify import verifyClass, verifyObject
 
-from waeup.sirp.app import University
-from waeup.sirp.interfaces import DuplicationError
-from waeup.sirp.testing import (
+from waeup.kofa.app import University
+from waeup.kofa.interfaces import DuplicationError
+from waeup.kofa.testing import (
     FunctionalLayer, doctestsuite_for_module, FunctionalTestCase)
-from waeup.sirp.university.certificate import Certificate
-from waeup.sirp.university.certificatescontainer import CertificatesContainer
-from waeup.sirp.university.interfaces import ICertificatesContainer
+from waeup.kofa.university.certificate import Certificate
+from waeup.kofa.university.certificatescontainer import CertificatesContainer
+from waeup.kofa.university.interfaces import ICertificatesContainer
 
 
@@ -132,5 +132,5 @@
         unittest.makeSuite(CertificatesContainerTests),
         doctestsuite_for_module(
-                'waeup.sirp.university.certificatescontainer'),
+                'waeup.kofa.university.certificatescontainer'),
         ))
     return suite
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_coursescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_coursescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_coursescontainer.py	(revision 7811)
@@ -21,6 +21,6 @@
 import unittest
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.university.interfaces import ICoursesContainer
-from waeup.sirp.university import CoursesContainer, Course
+from waeup.kofa.university.interfaces import ICoursesContainer
+from waeup.kofa.university import CoursesContainer, Course
 
 class CoursesContainerTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_export.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_export.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_export.py	(revision 7811)
@@ -22,10 +22,10 @@
 from zope.component import queryUtility
 from zope.interface.verify import verifyObject, verifyClass
-from waeup.sirp.interfaces import ICSVExporter
-from waeup.sirp.testing import SIRPUnitTestLayer
-from waeup.sirp.university import (
+from waeup.kofa.interfaces import ICSVExporter
+from waeup.kofa.testing import KOFAUnitTestLayer
+from waeup.kofa.university import (
     FacultiesContainer, Faculty, Department, Course, Certificate,
     )
-from waeup.sirp.university.export import (
+from waeup.kofa.university.export import (
     FacultyExporter, DepartmentExporter, CourseExporter,
     CertificateExporter, CertificateCourseExporter,
@@ -34,5 +34,5 @@
 class FacultyExporterTest(unittest.TestCase):
 
-    layer = SIRPUnitTestLayer
+    layer = KOFAUnitTestLayer
 
     def setUp(self):
@@ -123,5 +123,5 @@
     # Tests for DepartmentExporter
 
-    layer = SIRPUnitTestLayer
+    layer = KOFAUnitTestLayer
 
     def setUp(self):
@@ -214,5 +214,5 @@
     # Tests for CourseExporter
 
-    layer = SIRPUnitTestLayer
+    layer = KOFAUnitTestLayer
 
     def setUp(self):
@@ -307,5 +307,5 @@
     # Tests for CertificateExporter
 
-    layer = SIRPUnitTestLayer
+    layer = KOFAUnitTestLayer
 
     def setUp(self):
@@ -412,5 +412,5 @@
     # Tests for CertificateCourseExporter
 
-    layer = SIRPUnitTestLayer
+    layer = KOFAUnitTestLayer
 
     def setUp(self):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_facultiescontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_facultiescontainer.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_facultiescontainer.py	(revision 7811)
@@ -22,8 +22,8 @@
 from StringIO import StringIO
 from zope.interface.verify import verifyObject, verifyClass
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
-from waeup.sirp.university.interfaces import IFacultiesContainer
-from waeup.sirp.university import FacultiesContainer
-from waeup.sirp.university.facultiescontainer import AcademicsPlugin
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.university.interfaces import IFacultiesContainer
+from waeup.kofa.university import FacultiesContainer
+from waeup.kofa.university.facultiescontainer import AcademicsPlugin
 
 class FakeLogger(object):
@@ -90,5 +90,5 @@
         self.assertEqual(
             self._logger_factory.get_messages(),
-            'Could not create container for faculties in SIRP.\n'
+            'Could not create container for faculties in KOFA.\n'
             )
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_faculty.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_faculty.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_faculty.py	(revision 7811)
@@ -22,6 +22,6 @@
 import unittest
 from zope.interface.verify import verifyObject, verifyClass
-from waeup.sirp.university import Faculty, Department
-from waeup.sirp.university.interfaces import IFaculty, IDepartment
+from waeup.kofa.university import Faculty, Department
+from waeup.kofa.university.interfaces import IFaculty, IDepartment
 
 class FacultyAndDepartmentTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_university.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_university.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_university.py	(revision 7811)
@@ -19,6 +19,6 @@
 # Test the public API part of the university subpackage
 import unittest
-from waeup.sirp.university import *
-from waeup.sirp.testing import get_doctest_suite
+from waeup.kofa.university import *
+from waeup.kofa.testing import get_doctest_suite
 
 class UniversitySubpackageTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/vocabularies.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/vocabularies.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/vocabularies.py	(revision 7811)
@@ -22,8 +22,8 @@
 from zope.catalog.interfaces import ICatalog
 from zope.component import getUtility
-from waeup.sirp.interfaces import SimpleSIRPVocabulary, ISIRPUtils
-from waeup.sirp.interfaces import MessageFactory as _
+from waeup.kofa.interfaces import SimpleKOFAVocabulary, IKOFAUtils
+from waeup.kofa.interfaces import MessageFactory as _
 
-course_levels = SimpleSIRPVocabulary(
+course_levels = SimpleKOFAVocabulary(
     (_('Pre-Studies'),10),
     (_('100 (Year 1)'),100),
@@ -41,5 +41,5 @@
     """
     def getValues(self, context):
-        semesters_dict = getUtility(ISIRPUtils).getSemesterDict()
+        semesters_dict = getUtility(IKOFAUtils).getSemesterDict()
         return semesters_dict.keys()
 
@@ -48,5 +48,5 @@
 
     def getTitle(self, context, value):
-        semesters_dict = getUtility(ISIRPUtils).getSemesterDict()
+        semesters_dict = getUtility(IKOFAUtils).getSemesterDict()
         return semesters_dict[value]
 
@@ -56,5 +56,5 @@
     """
     def getValues(self, context):
-        insttypes_dict = getUtility(ISIRPUtils).getInstTypeDict()
+        insttypes_dict = getUtility(IKOFAUtils).getInstTypeDict()
         return sorted(insttypes_dict.keys())
 
@@ -63,5 +63,5 @@
 
     def getTitle(self, context, value):
-        insttypes_dict = getUtility(ISIRPUtils).getInstTypeDict()
+        insttypes_dict = getUtility(IKOFAUtils).getInstTypeDict()
         return insttypes_dict[value]
 
@@ -71,5 +71,5 @@
     """
     def getValues(self, context):
-        appcats_dict = getUtility(ISIRPUtils).getAppCatDict()
+        appcats_dict = getUtility(IKOFAUtils).getAppCatDict()
         return sorted(appcats_dict.keys())
 
@@ -78,5 +78,5 @@
 
     def getTitle(self, context, value):
-        appcats_dict = getUtility(ISIRPUtils).getAppCatDict()
+        appcats_dict = getUtility(IKOFAUtils).getAppCatDict()
         return appcats_dict[value]
 
@@ -86,5 +86,5 @@
     """
     def getValues(self, context):
-        studymodes_dict = getUtility(ISIRPUtils).getStudyModesDict()
+        studymodes_dict = getUtility(IKOFAUtils).getStudyModesDict()
         return sorted(studymodes_dict.keys())
 
@@ -93,5 +93,5 @@
 
     def getTitle(self, context, value):
-        studymodes_dict = getUtility(ISIRPUtils).getStudyModesDict()
+        studymodes_dict = getUtility(IKOFAUtils).getStudyModesDict()
         return studymodes_dict[value]
 

Index: main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py	(revision 7811)
@@ -26,7 +26,7 @@
 from zope.index.text.parsetree import ParseError
 from zope.intid import IIntIds
-#from waeup.sirp.catalog import QueryResultItem
-from waeup.sirp.interfaces import IUniversity, IQueryResultItem
-from waeup.sirp.university.interfaces import (
+#from waeup.kofa.catalog import QueryResultItem
+from waeup.kofa.interfaces import IUniversity, IQueryResultItem
+from waeup.kofa.university.interfaces import (
     ICourse, ICertificateCourse, IDepartment,
     ICertificate,